@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 0, 9)
+__version__ = (0, 0, 11)
 __all__ = [
     "create_cookie", "create_morsel", "to_cookie", "to_morsel", 
     "cookie_to_morsel", "morsel_to_cookie", "cookies_to_dict", 
@@ -326,9 +326,9 @@ def cookies_to_dict(
         def predicate(_, cookie, /) -> bool:
             if isinstance(cookie, str):
                 return True
-            if (domain := getattr(cookie, "domain", "")) and not domain.endswith(urlp.netloc):
+            if (domain := getattr(cookie, "domain", "")) and not urlp.netloc.endswith(domain):
                 return False
-            if (url_path := urlp.path) and commonpath((url_path, getattr(cookie, "path", "") or "")) != url_path:
+            if (path := getattr(cookie, "path", "")) and commonpath((path, urlp.path or "/")) != path:
                 return False
             return True
     elif isinstance(predicate, Container):
@@ -387,9 +387,9 @@ def cookies_to_str(
         def predicate(_, cookie, /) -> bool:
             if isinstance(cookie, str):
                 return True
-            if (domain := getattr(cookie, "domain", "")) and not domain.endswith(urlp.netloc):
+            if (domain := getattr(cookie, "domain", "")) and not urlp.netloc.endswith(domain):
                 return False
-            if (url_path := urlp.path) and commonpath((url_path, getattr(cookie, "path", "") or "")) != url_path:
+            if (path := getattr(cookie, "path", "")) and commonpath((path, urlp.path or "/")) != path:
                 return False
             return True
     elif isinstance(predicate, Container):
